#
# spec file for package python-tomlkit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-tomlkit
Version:        0.12.4
Release:        1.2
Summary:        Style preserving TOML library
License:        MIT
URL:            https://github.com/sdispater/tomlkit
Source:         https://files.pythonhosted.org/packages/source/t/tomlkit/tomlkit-%{version}.tar.gz
BuildRequires:  %{python_module PyYAML >= 6.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Style preserving TOML library

%prep
%setup -q -n tomlkit-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/tomlkit
%{python_sitelib}/tomlkit-%{version}*-info

%changelog
* Wed Mar 13 2024 Dirk Müller <dmueller@suse.com>
- update to 0.12.4:
  * Support `|` and `|=` operator for tables, and support `+` and
    `+=` operator for arrays.
  * Fix an index error when setting dotted keys in a table.
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.3:
  * Improve the performance when parsing a table with nested
    dotted keys. (#193)
  * Keep the newlines when replacing a table. (#323)
  * Fixed a bug that overwriting a sub table with a plain value
    raises an error. (#313)
  * Correct the return type of integer division. (#312)
* Thu Sep  7 2023 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * Make float and int hashable.
  * Allow users to specify encoders for custom types. (#296)
  * Fix the incorrect sort when building a table with dotted
    keys.
  * Complete the methods required for integer and float items.
  * Replace the deprecated usage of `datetime.utcnow()`. (#308)
  * Minor performance improvements when iterating over the escape
    sequences. (#304)
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 0.11.8:
  * Remove the extra indentations added when parsing nested sub-
    tables.
  * Ignore the CRLF immediately following a multiple basic string
    opening.
  * Stringifying subtables and nested tables in arrays of tables.
  * Messed table structure when building a table with dotted
    keys.
* Tue Apr 25 2023 Matej Cepl <mcepl@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Tue Apr 18 2023 Matej Cepl <mcepl@suse.com>
- Don't add dependency on full poetry, when poetry-core is enough.
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.11.7:
  * Parse empty table name if it is quoted. (#258)
  * Fix a bug that remove last element of an Inline Table leaves
    a comma. (#259)
  * Parse datetime when it is followed by a space. (#260)
  * Fix the `unwrap()` method for `Container` children values
    which sometimes returns an internal object if the table is an
    out-of-order table. (#264)
  * Fix the wrong return type when doing arithmetic operations
    between integers and floats. (#270)
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.11.6
  Fixed
  * Allow broader type for toml file path value (#243)
  * Auto-determine if a table is a super table if not specified explicitly. (#245)
* Mon Oct  3 2022 Dirk Müller <dmueller@suse.com>
- update to 0.11.5:
  * Fix the type annotation of `unwrap()` and datetime parsing.
  * Clear the existing table header when it is adding to another table.
  * Fix a bug that escape chars are lost after concat with another string.
  * Fix a rendering issue of tables inside arrays or inline tables.
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.11.4:
  * Fix a memory leak caused by `lru_cache` on methods.
  * Fix a regression issue that copying an array results in extra `None` items.
  * Fix a regression of `array.add_line` that it incorrectly adds a comma to
    non-value lines.
  * Fix adding float to an integer value.
  * Keep the end-of-array style when adding items to or removing items from an array.
  * Fix a bug of redundant table header shown when removing children from a
    super table.
* Wed Jul 13 2022 Ben Greiner <code@bnavigator.de>
- Update to version 0.11.1
  * Keep consistent line endings when changing files. (#201)
  * Make KeyAlreadyPresent and InvalidStringError subclasses of
    ParseError. (#202)
  * Remove empty table from OutOfOrderTableProxy when deleting
    items. (#204)
  * Raise errors when trying to access unsupported methods on
    OutOfOrderTableProxy. (#205)
  * Fix unwrap() for String values to remove the quotes. (#199)
- Release 0.11.0
  * Add unwrap method to recursive convert to plain old python
    objects by @syntapy in #187
  * Remove the is_tomlkit check by @frostming in #195
- Release 0.10.2
  * Use the plain python string representation of Key in
    KeyAlreadyPresent error message. (#185)
  * Fix the astimezone() and replace() methods of datetime objects.
    (#188)
  * Add type definitions for items() function. (#190)
- Release 0.10.1
  * Preserve the newlines before super tables when rendering.
    (#178)
  * Fix the bug that comments are appended with comma when
    rendering a multiline array. (#181)
- Release 0.10.0
  * Fix the only child detection when creating tables. (#175)
  * Include the docs/ directory and CHANGELOG.md in sdist tarball.
    (#176)
  * Add keyword arguments to string API to allow selecting the
    representation type. (#177)
- Release 0.9.2
  * When a table's only child is a table or array of table, it is
    created as a super table. (#175)
- Release 0.9.1
  * Fix a bug of separators not being kept when replacing the
    value. (#170)
  * Tuples should be dumped as TOML arrays. (#171)
- Release 0.9.0
  * Add an argument to allow table to be super table by @frostming
    in #159
  * Support adding item with dotted key by @frostming in #162
  * Initialize Sphinx docs by @frostming in #163
  * Fix values similar to booleans being incorrectly parsed to
    booleans by @MrGreenTea in #168
* Thu Jan 20 2022 Matej Cepl <mcepl@suse.com>
- Update to version 0.8.0:
  - Drop support for Python<3.6.
  - Comply with TOML v1.0.0.
  - And many bug fixes
* Mon Oct  5 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 0.7.0
  * Added support for sorting keys when dumping raw
    dictionaries by passing sort_keys=True to dumps() (#103).
  * Keys are not longer sorted by default when dumping a raw
    dictionary but the original order will be preserved (#103).
  * Fixed compliance with the 1.0.0rc1 TOML specification (#102).
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.6.0
  * Added support for heterogeneous arrays
* Thu Mar 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Wed Mar 11 2020 pgajdos@suse.com
- version update to 0.5.11
  * Fix containers and our of order tables dictionary behavior (#82))
  * Fixed out of order tables not behaving properly (#79)
  * Fixed the behavior for out of order tables (#68).
  * Fixed parsing errors when single quotes are present in a table name (#71).
  * Fixed parsing errors when parsing some table names (#76).
* Thu Nov 28 2019 Matej Cepl <mcepl@suse.com>
- Update to 0.5.8:
  - Added support for producing multiline arrays
* Tue Oct  8 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.7:
  * Fixed handling of inline tables.
  * Fixed boolean comparison.
  * Fixed appending inline tables to tables.
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.5:
  * Fixed display of inline tables after element deletion.
  * Fixed the handling of inline tables.
  * Fixed date, datetime and time handling on Python 3.8.
  * Fixed behavior for sub table declaration with intermediate tables.
  * Fixed behavior of setdefault() on containers (Thanks to @AndyKluger).
  * Fixed tables string representation.
* Fri Mar  1 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.5.3
